***************
Devis : Exemple
***************

.. sb_coords::

:version: 0.1

.. |date| date:: %d/%m/%Y

.. generated with command : rst2pdf demo.rst -o demo.pdf -l fr_FR -s ~/.sveebiz/commons.style -b1
.. requires : docutils-0.7 , ReportLab2.4, rst2pdf-0.14.2

.. raw:: pdf

   PageBreak oneColumn

.. header::

   ###Section###

.. footer::

   Page ###Page###

.. contents::

.. section-numbering::

============
Introduction
============

Suspendisse congue tempor consequat. Integer fringilla, odio non ultrices mattis, arcu elit adipiscing magna, at sollicitudin tortor odio ac dui. 

Vivamus quis orci enim. Pellentesque fringilla, nibh eu feugiat ullamcorper, mauris tellus interdum arcu, id rutrum lorem neque in ipsum. 

===============
Fonctionnalités
===============

-----------
Hello World
-----------

Pellentesque rhoncus lacinia scelerisque. Donec ut nulla urna, id sagittis tellus. Nullam molestie, dui non placerat facilisis, purus augue iaculis sapien, eu lobortis nunc felis eu lorem.

Ut et dui quam, in volutpat diam. Praesent vel vulputate neque! Curabitur sit amet erat nisl, gravida vestibulum tortor. Integer aliquam tempor arcu et scelerisque. In nec urna in metus porta fermentum at eget massa. Morbi id mi eget nunc hendrerit euismod. Nunc elit risus, feugiat vel auctor eget; hendrerit id nisl. Nunc non neque nisl; sit amet placerat lorem? Donec nec luctus nulla. Phasellus eget nisl leo, a euismod nisi.Aenean quis felis eget odio ultrices imperdiet id id leo? Nam ut erat vel dolor venenatis sollicitudin. Pellentesque et magna neque, at vehicula augue? Vestibulum aliquet euismod purus quis fermentum. Praesent est quam, sollicitudin a pharetra sit amet, pretium vel nunc. Aenean convallis neque id nisi dignissim euismod. Pellentesque a nisl id libero tincidunt pretium. Nam rhoncus dignissim nisi! Ut egestas neque dictum elit blandit aliquet. Class aptent taciti sociosqu ad litora torquent per conubia nostra, per inceptos himenaeos. Sed ipsum enim, facilisis nec eleifend et, condimentum sed lectus. Vestibulum hendrerit magna placerat arcu vehicula quis ullamcorper arcu pellentesque. Integer a turpis eget enim tincidunt dictum. Etiam eget interdum mauris. Vivamus fermentum hendrerit metus vulputate hendrerit. Cras odio purus, molestie quis semper a, hendrerit sed ipsum.Maecenas faucibus iaculis mattis? Cum sociis natoque penatibus et magnis dis parturient montes, nascetur ridiculus mus. Donec volutpat lectus ac turpis ultricies aliquet. Donec metus dolor, aliquam in aliquam quis, commodo at libero. Cras et nisl nibh? Sed egestas consequat convallis. Sed et felis enim. Ut nunc lacus, dapibus a varius eget, tempor eu mauris. Proin ut turpis vestibulum lectus sagittis vehicula. Sed ac nisi in odio fringilla luctus. Suspendisse et nisl nunc. Nulla auctor diam sit amet urna dignissim ultricies. Nulla viverra ante vel purus tristique sollicitudin. Sed nec orci massa! Proin scelerisque quam vel enim feugiat faucibus! Nam vitae enim vel sapien egestas luctus. Phasellus dignissim risus vitae risus dignissim hendrerit ut ac lorem. Fusce at sem erat. Suspendisse non elit a nisi pretium tempor aliquet vel risus.Mauris augue elit, dictum sed tincidunt vel, congue in metus. Maecenas tempus cursus fermentum. Quisque sit amet felis quis orci rhoncus tristique. Donec suscipit iaculis sapien in elementum. Nunc vestibulum eros feugiat arcu fermentum euismod. Etiam aliquet nisl sit amet orci venenatis pulvinar? Aliquam facilisis ipsum eget neque vestibulum fermentum. Donec non arcu eget mi tincidunt cursus. Etiam ornare fringilla arcu, at fermentum erat tincidunt ut. In consequat pharetra vestibulum! Aenean ultricies metus id lorem ornare tristique? Duis nisl nunc; malesuada ullamcorper tincidunt nec, placerat et massa.Nunc et quam vitae est pretium convallis. Maecenas sem nisi, malesuada iaculis ultrices tincidunt, faucibus posuere nisl. Maecenas id pulvinar odio. Duis id turpis quis sem interdum porttitor. Maecenas rutrum pellentesque libero quis tincidunt. Curabitur rhoncus metus quis orci bibendum bibendum. Nam aliquet aliquet urna at tincidunt. Nam sagittis eleifend mattis. Mauris non nunc purus; vel congue tellus. Maecenas nisi erat, imperdiet ac ornare a, consectetur et lacus. Proin feugiat tortor eget velit tristique tristique. Suspendisse ut tincidunt purus. Nam ullamcorper sagittis sollicitudin.Proin id nunc dictum lorem accumsan hendrerit in a ligula? Morbi ut justo et massa suscipit pretium! Aenean laoreet tellus non purus eleifend venenatis. Integer ultricies quam vel nibh molestie ac vehicula sapien hendrerit. Vestibulum non neque diam, sit.

.. sb_delay_add:: 42

=========
Technique
=========

Les choix technologiques sont :

.. sb_softwares:: python django postgres jquery subversion redmine

====
Coût
====

.. sb_cost_section:: standard
